@@ -1,8 +1,33 @@
 from .base import BaseModel, ObjectListModel
 
+class Prijscategorie(BaseModel):
+    
+    def __init__(self,
+        label=None,
+        label_id=None,
+        type=None,
+        korting=None,
+        verkoopprijs_excl=None,
+        verkoopprijs_incl=None           
+    ):
+        
+        super().__init__()
+        
+        self.label = label
+        self.label_id = label_id
+        self.type = type
+        self.korting = korting
+        self.verkoopprijs_excl = verkoopprijs_excl
+        self.verkoopprijs_incl = verkoopprijs_incl
+
+class Prijscategorieen(ObjectListModel):
+    def __init__(self):
+        super().__init__(list=[], listObject=Prijscategorie)
+        
 class Artikel(BaseModel):
     
     def __init__(self,
+        id=None,
         naam=None,
         beschrijving=None,
         SKU=None,
@@ -16,11 +41,13 @@ class Artikel(BaseModel):
         bestellingtype=None,
         units_per_bestelling=None,
         BTW=None,
-        status=None
+        status=None,
+        prijscategorieen=None,
     ):
 
         super().__init__()
 
+        self.id = id
         self.naam = naam
         self.beschrijving = beschrijving
         self.SKU = SKU
@@ -35,6 +62,7 @@ class Artikel(BaseModel):
         self.units_per_bestelling = units_per_bestelling
         self.BTW = BTW
         self.status = status
+        self.prijscategorieen = prijscategorieen if prijscategorieen else Prijscategorieen()
 
 class Artikels(ObjectListModel):
     def __init__(self):
